==> 1.0.0-dev.1.tar.gz: lib/src/agent/navigation_observer.dart <==
import 'package:flutter/widgets.dart';
import 'package:tingyun_flutter_plugin/src/agent/agent_impl.dart';
import 'package:tingyun_flutter_plugin/src/agent/interface/newlens_agent.dart';

import '../../tingyun_flutter_plugin.dart';
import 'util/logger.dart';

/// Navigation observer which is reporting routes
class TingyunNavigationObserver extends RouteObserver<PageRoute<dynamic>>{
  Tingyun _tingyun;

  TingyunNavigationObserver(): _tingyun = Tingyun();

  /// Private constructor which should only be used for testing purpose
  @visibleForTesting
  TingyunNavigationObserver.private({Tingyun tingyun}): _tingyun = tingyun;

  @override
  void didPush(Route route, Route previousRoute) {
    super.didPush(route, previousRoute);
    Logger().d('didPush route type:${route.runtimeType.toString()}, '
        'previousRoute:${previousRoute.runtimeType.toString()}');
    if (route is PageRoute) {
      _reportRoute(route);
    }
  }

  @override
  void didReplace({Route newRoute, Route oldRoute}) {
    super.didReplace(newRoute: newRoute, oldRoute: oldRoute);
    Logger().d('didReplace newRoute type:${newRoute.runtimeType.toString()}, '
        'oldRoute:${oldRoute.runtimeType.toString()}');
    if (newRoute is PageRoute) {
      _reportRoute(newRoute);
    }
  }

  @override
  void didPop(Route route, Route previousRoute) {
    super.didPop(route, previousRoute);
    Logger().d('didPop route:${route.runtimeType.toString()}, '
        'previousRoute:${previousRoute.runtimeType.toString()}');
    if (previousRoute is PageRoute && route is PageRoute) {
      _reportRoute(previousRoute);
    }
  }

  void _reportRoute(PageRoute route){
    Logger().d('route.settings.name:${route.settings.name}');
    if(route.settings.name != null){
      // Route has a name and will be reported
      ///记录一下
      TingyunFlutterImpl.currentRoutePage = route.settings.name;

      // TingyunRootAction pageRootAction = _tingyun
      //     .enterAction("Navigation to ${route.settings.name}");
      // Logger().d('page leaveAction:${route.settings.name}');
      //
      // Future.delayed( Duration(milliseconds: this._tingyun.getPageLoadingDuration()), (){
      //     pageRootAction.leaveAction(props: <String, dynamic>{
      //       "networkDelay": this._tingyun.getNetworkDelay()
      //     }, type: 1);
      // });
    }else{
      Logger().d(
          "Navigation occurred but Route will not be reported as it has no name!",
          logType: LogType.Info);
    }
  }

}

==> 2.1.0.tar.gz: lib/src/agent/navigation_observer.dart <==
import 'package:flutter/widgets.dart';
import 'package:tingyun_flutter_plugin/src/agent/agent_impl.dart';
import 'package:tingyun_flutter_plugin/src/agent/interface/newlens_agent.dart';

import '../../tingyun_flutter_plugin.dart';
import 'util/logger.dart';

/// Navigation observer which is reporting routes
class TingyunNavigationObserver extends RouteObserver<PageRoute<dynamic>>{
  Tingyun? _tingyun;

  TingyunNavigationObserver(): _tingyun = Tingyun();

  /// Private constructor which should only be used for testing purpose
  @visibleForTesting
  TingyunNavigationObserver.private({Tingyun? tingyun}): _tingyun = tingyun;

  @override
  void didPush(Route route, Route? previousRoute) {
    super.didPush(route, previousRoute);
    Logger().d('didPush route type:${route.runtimeType.toString()}, '
        'previousRoute:${previousRoute.runtimeType.toString()}');
    if (route is PageRoute) {
      _reportRoute(route);
    }
  }

  @override
  void didReplace({Route? newRoute, Route? oldRoute}) {
    super.didReplace(newRoute: newRoute, oldRoute: oldRoute);
    Logger().d('didReplace newRoute type:${newRoute.runtimeType.toString()}, '
        'oldRoute:${oldRoute.runtimeType.toString()}');
    if (newRoute is PageRoute) {
      _reportRoute(newRoute);
    }
  }

  @override
  void didPop(Route route, Route? previousRoute) {
    super.didPop(route, previousRoute);
    Logger().d('didPop route:${route.runtimeType.toString()}, '
        'previousRoute:${previousRoute.runtimeType.toString()}');
    if (previousRoute is PageRoute && route is PageRoute) {
      _reportRoute(previousRoute);
    }
  }

  void _reportRoute(PageRoute route){
    Logger().d('route.settings.name:${route.settings.name}');
    if(route.settings.name != null){
      // Route has a name and will be reported
      ///记录一下
      TingyunFlutterImpl.currentRoutePage = route.settings.name ?? "";

      // TingyunRootAction pageRootAction = _tingyun
      //     .enterAction("Navigation to ${route.settings.name}");
      // Logger().d('page leaveAction:${route.settings.name}');
      //
      // Future.delayed( Duration(milliseconds: this._tingyun.getPageLoadingDuration()), (){
      //     pageRootAction.leaveAction(props: <String, dynamic>{
      //       "networkDelay": this._tingyun.getNetworkDelay()
      //     }, type: 1);
      // });
    }else{
      Logger().d(
          "Navigation occurred but Route will not be reported as it has no name!",
          logType: LogType.Info);
    }
  }

}
